Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3785)

Unified Diff: chrome/test/base/chrome_render_view_test.cc

Issue 707173004: Refactor Autofill for out of process iframes (OOPIF). (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: mem leak Created 6 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/renderer/chrome_content_renderer_client.cc ('k') | components/autofill.gypi » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/test/base/chrome_render_view_test.cc
diff --git a/chrome/test/base/chrome_render_view_test.cc b/chrome/test/base/chrome_render_view_test.cc
index da8e1458ffa5275a8dd77c551fe0fe65cbe7afdc..4f47f69eb007c99a4b791220cd01c23e595b2ae5 100644
--- a/chrome/test/base/chrome_render_view_test.cc
+++ b/chrome/test/base/chrome_render_view_test.cc
@@ -64,13 +64,16 @@ void ChromeRenderViewTest::SetUp() {
content::RenderViewTest::SetUp();
// RenderView doesn't expose its Agent objects, because it has no need to
// store them directly (they're stored as RenderViewObserver*). So just
// create another set.
- password_autofill_agent_ = new autofill::TestPasswordAutofillAgent(view_);
- password_generation_ = new autofill::TestPasswordGenerationAgent(view_);
+ password_autofill_agent_ =
+ new autofill::TestPasswordAutofillAgent(view_->GetMainRenderFrame());
+ password_generation_ =
+ new autofill::TestPasswordGenerationAgent(view_->GetMainRenderFrame());
autofill_agent_ =
- new AutofillAgent(view_, password_autofill_agent_, password_generation_);
+ new AutofillAgent(view_->GetMainRenderFrame(), password_autofill_agent_,
+ password_generation_);
}
void ChromeRenderViewTest::TearDown() {
« no previous file with comments | « chrome/renderer/chrome_content_renderer_client.cc ('k') | components/autofill.gypi » ('j') | no next file with comments »
@@ -64,13 +64,16 @@ void ChromeRenderViewTest::SetUp() {
content::RenderViewTest::SetUp();
- // RenderView doesn't expose its Agent objects, because it has no need to
- // store them directly (they're stored as RenderViewObserver*). So just
+ // RenderFrame doesn't expose its Agent objects, because it has no need to
+ // store them directly (they're stored as RenderFrameObserver*). So just
// create another set.

Powered by Google App Engine
This is Rietveld 408576698